from setuptools import setup, find_packages
setup(name='sas_oda',
version='1.0.0',
description='',
author='hoor0015',
author_email='hoor0015@gmail.com',
license='MIT',
install_requires=['saspy>=3.7.3'],
packages=find_packages(),
)